==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/pt_PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_PT">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Bem-vindo a %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Atenção, Caps Lock está ligada!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Disposição</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Sessão</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>A autenticação falhou</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Autentificação com sucesso</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Escreva o seu nome de utilizador e senha</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sessão</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Escolha o seu nome de utilizador e escreva a senha</translation>
    </message>
</context>
</TS>

==> sddm_0.18.1.orig.tar.gz: sddm-0.18.1/data/translations/pt_PT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Bem-vindo ao %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Atenção, Caps Lock está ativo!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Disposição</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Falha de autenticação</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Autenticação efetuada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Escreva o seu nome de utilizador e a senha</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sessão</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Escolha o seu nome de utilizador e escreva a senha</translation>
    </message>
</context>
</TS>
